BasicRegisters

Struct BasicRegisters 

pub struct BasicRegisters<Reg, const ZEROSTORE: bool = false>
where Reg: BasicRegister,
{ /* private fields */ }
A basic set of RISC-V GPRs (General Purpose Registers).

ZEROSTORE generic determines whether to zero x0 register on write instead of checking register index on read. match loop usually performs better with branching, while threaded execution benefits from zeroing.