pub struct IllegalEcallSystemInstructionHandler;Expand description
System instruction handler that results in illegal instruction for all system calls and does nothing for other system instructions.
Being stateless, it can be used as the whole execution environment of a configuration that needs nothing else from it.