BasicInstructionFetcher

Struct BasicInstructionFetcher 

pub struct BasicInstructionFetcher<I, CustomError = CustomErrorPlaceholder>
where I: Instruction,
{ /* private fields */ }
Basic instruction fetcher implementation.

This implementation is intentionally basic and correct, but not the most performant. It is possible to have a more efficient implementation that skips certain checks by placing additional constraints on the constructor.

Note that it loads instructions from anywhere in memory. This works, but it is likely that you want to restrict this to a specific executable region of memory.

Implementations

Source

impl<I, CustomError> BasicInstructionFetcher<I, CustomError>
where I: Instruction,

pub fn new( return_trap_address: <<I as Instruction>::Reg as Register>::Type, pc: <<I as Instruction>::Reg as Register>::Type, ) -> Self

Create a new instance.

return_trap_address is the address at which the interpreter will stop execution (gracefully).