pub struct BasicInstructionFetcher<I, CustomError = CustomErrorPlaceholder>where
I: Instruction,{ /* private fields */ }Expand description
Basic instruction fetcher implementation.
This implementation is intentionally basic and correct, but not the most performant. It is possible to have a more efficient implementation that skips certain checks by placing additional constraints on the constructor.
Note that it loads instructions from anywhere in memory. This works, but it is likely that you want to restrict this to a specific executable region of memory.
Implementations
Sourceimpl<I, CustomError> BasicInstructionFetcher<I, CustomError>where
I: Instruction,
impl<I, CustomError> BasicInstructionFetcher<I, CustomError>where
I: Instruction,