BasicMemory

Struct BasicMemory 

pub struct BasicMemory<const BASE_ADDR: u64, const SIZE: usize> { /* private fields */ }
Basic memory implementation.

Flat structure, no rwx protections, no alignment requirements. It uses stack, so for larger allocation it’ll need to be boxed (zero-initialized is fine) or a custom implementation to be used.

This implementation is intentionally basic and correct, but not the most performant. It is possible to have a more efficient implementation that skips certain checks by placing additional constraints on the program.

This works for simpler cases, while a more sophisticated implementation might prevent certain memory from being writable, supporting actual virtual memory with dynamically allocated memory pages, etc.

Implementations

Source

impl<const BASE_ADDR: u64, const SIZE: usize> BasicMemory<BASE_ADDR, SIZE>

pub fn get_mut_bytes( &mut self, address: u64, size: usize, ) -> Result<&mut [u8], VirtualMemoryError>

Get a mutable slice of memory.

This is primarily useful for setting up the program and should not be used beyond that.