IllegalEcallSystemInstructionHandler

Struct IllegalEcallSystemInstructionHandler 

pub struct IllegalEcallSystemInstructionHandler;
System instruction handler that results in illegal instruction for all system calls and does nothing for other system instructions